<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define('THEMEROOT', get_stylesheet_directory_uri());
define('IMAGES', THEMEROOT . '/images');
define('SCRIPTS', THEMEROOT . '/js');
require_once('wp_bootstrap_navwalker.php');
require_once('phone_widget.php');


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */

if (!function_exists('alpha_setup')) {
    function alpha_setup()
    {
        /**
         * Make the theme available for translation.
         */
        $lang_dir = THEMEROOT . '/languages';
        load_theme_textdomain('alpha', $lang_dir);

        /**
         * Add support for post formats.
         */
//		add_theme_support( 'post-formats',
//			array(
//				'gallery',
//				'link',
//				'image',
//				'quote',
//				'video',
//				'audio'
//			)
//		);

        /**
         * Add support for automatic feed links.
         */
        add_theme_support('automatic-feed-links');
        add_theme_support('widgets');

        /**
         * Add support for post thumbnails.
         */
        add_theme_support('post-thumbnails');
        add_theme_support( 'yoast-seo-breadcrumbs' );


        /**
         * Register nav menus.
         */
        register_nav_menus(
            array(
                'main' => __('القائمة الرئيسية', 'alpha'),
                'footer1' => __('قائمة الفوتر1', 'alpha'),
				'footer2' => __( 'قائمة الفوتر2 ', 'alpha' )



            )
        );
    }

    add_action('after_setup_theme', 'alpha_setup');
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if (!function_exists('alpha_scripts')) {
    function alpha_scripts()
    {
        // Adds support for pages with threaded comments
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        // Register scripts
        wp_register_script('bootstrap-js', SCRIPTS . '/bootstrap.min.js', array('jquery'), false, true);
//		wp_register_script( 'swip', SCRIPTS . '/jquery.touchSwipe.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'modernizr', SCRIPTS . '/modernizr.custom.97074.js', array( 'jquery' ), false, true );
        wp_register_script('owlcarousel', SCRIPTS . '/owl.carousel.min.js', array('jquery'), false, true);
        wp_register_script('wow', SCRIPTS . '/wow.min.js', array('jquery'), false, true);
//		wp_register_script( 'lightslider.min', SCRIPTS . '/lightslider.min.js', array( 'jquery' ), false, true );


        // Load the custom scripts
        wp_enqueue_script('bootstrap-js');
//		wp_enqueue_script( 'swip' );
//		wp_enqueue_script( 'modernizr' );
        wp_enqueue_script('owlcarousel');
        wp_enqueue_script('wow');
//		wp_enqueue_script( 'lightslider.min' );


        wp_register_script('custom', SCRIPTS . '/custom.js', array('jquery'), false, true);
        wp_enqueue_script('custom');


        // Load the stylesheets
        wp_enqueue_style('bootstrap', THEMEROOT . '/css/bootstrap.min.css');
        wp_enqueue_style('Fontawesome', THEMEROOT . '/css/font-awesome.min.css');
        wp_enqueue_style('animate', THEMEROOT . '/css/animate.css');
        wp_enqueue_style('owl.carousel', THEMEROOT . '/css/owl.carousel.css');
//		wp_enqueue_style( 'sinster', THEMEROOT . '/css/sinister.css' );
//		wp_enqueue_style( 'lightslider', THEMEROOT . '/css/lightslider.min.css' );

        if (is_rtl()) {

            wp_enqueue_style('bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.min.css');
            wp_enqueue_style('rtl', THEMEROOT . '/style.css');

        } else {
            wp_enqueue_style('en', THEMEROOT . '/en.css');
        }

    }

    add_action('wp_enqueue_scripts', 'alpha_scripts');
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */
register_post_type('slider', array(

    'public' => true,

    'hierarchical' => false,

    'exclude_from_search' => false,

    'has_archive' => true,

    'rewrite' => array('slug' => 'slider'),

    'capability_type' => 'post',

    'menu_icon' => 'dashicons-store',

    'taxonomies' => array('post_tag'),

    'labels' => array(

        'name' => 'السلايدر',

        'menu_name' => 'السلايدر',

        'name_admin_bar' => ' سلايدر'


    ),

    'supports' => array('title', 'editor', 'tags', 'thumbnail')

));
/*************************************************/
/* Register Taxonami */
/*************************************************/
//add_action( 'init', 'create_sections' );
//
//function create_sections() {
//	register_taxonomy(
//		'sections',
//		'products',
//		array(
//			'label'             => __( 'تصنيفات الخدمات' ),
//			'hierarchical'      => true,
//			'show_ui'           => true,
//			'show_admin_column' => true,
//			'show_in_nav_menus' => true,
//			'show_tagcloud'     => true,
//			'public'            => true
//		)
//
//	);
//
//}


/*************************************************/
/* Page Option */
/*************************************************/

if (function_exists('acf_add_options_page')) {

    acf_add_options_page(array(
        'page_title' => 'العملاء',
        'menu_title' => 'العملاء',
        'menu_slug' => 'opinions',
        'capability' => 'edit_posts',
        'update_button' => 'حفظ ',
        'redirect' => false
    ));

}
if (function_exists('acf_add_options_page')) {

    acf_add_options_page(array(
        'page_title' => 'اعدادات القالب',
        'menu_title' => 'اعدادات القالب',
        'menu_slug' => 'theme-general-settings',
        'capability' => 'edit_posts',
        'update_button' => 'حفظ الاعدادات',
        'redirect' => false
    ));

}

function mytheme_admin_bar_render()
{
    global $wp_admin_bar;
    $wp_admin_bar->add_menu(array(
        'id' => 'themeoptions',
        'title' => ' &#12245; ' . __('اعدادات القالب', 'some-textdomain'),
        'href' => admin_url('admin.php?page=theme-general-settings'),
        'icon' => 'img'
    ));
}

// and we hook our function via
add_action('wp_before_admin_bar_render', 'mytheme_admin_bar_render');


/*************************************************/
/* Sidebar */
/*************************************************/
if (function_exists('register_sidebar')) {
    register_sidebar(
        array(
            'name' => 'sidebar',
            'id' => 'sidebar',
            'description' => 'Sidebar',
            'before_widget' => '<div class="rest-of-news">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="box-section-title">',
            'after_title' => '</h6>'

        )
    );
}


